@@ -1,6 +1,5 @@
 # SPDX-FileCopyrightText: 2023-present Aaron <aaron@framelunch.jp>
 #
 # SPDX-License-Identifier: MIT
-from .bootstrap import ensure_requirements
 from .command import Command, sub_cmds
-from .config import get_config, copy_config, include, config_var, configure
+from .config import get_config, copy_config, include, config_var, configure, set_config
